/****************************************************************************

FILE	emit.c

PURPOSE 
    This file contains main emitting function for expression tree
    
*****************************************************************************/
/*****************************************************************************                                                                              
 Copyright (c) 1995
      Robert J. Mercier
 Copyright 2000
      Vahur Krouverk

THIS CODE IS SUPPLIED ``AS IS'' WITH NO WARRANTY EXPRESSED
OR IMPLIED.  NO CLAIMS IS MADE TO IT'S SUITABILITY FOR
ANY PURPOSE AND NO RESPONSIBILITY IS ACCEPTED FOR ANY DAMAGES
OF ANY KIND RESULTING FROM IT'S USE.

When (if) this code is included into POV the usual POV legal stuff will apply.

*****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include "shade.h"
#include "y.tab.h"
#include "opcodes.h"
#include "gener.h"
#include "shdrglob.h"

/* expression tree length in elements */
int llen(struct tree *p)
{
    int l = 0;
    while (p != NULL) {
        l++;
        p = p->kids[0];
    }
    return l;
}

int translate_cspace(int cspace)
{

    int rv=0;
    
    switch(cspace){
        case tCSRGB:
            rv = 1;
            break;
        case tCSHSV:
            rv = 2;
            break;
        case tCSHSL:
            rv = 3;
            break;
        case tCSXYZ:
            rv = 4;
            break;
        case tCSXY_Y:
            rv = 5;
            break;
        case tCSYIQ:
            rv = 6;
            break;
    }
    return rv;
}

int translate_pspace(int pspace)
{
    int rv=0;
    switch(pspace){
        case tPSRASTER:
            rv=PS_RASTER;
            break;
        case tPSSCREEN:
            rv=PS_SCREEN;
            break;
        case tPSCAMERA:
            rv=PS_CAMERA;
            break;
        case tPSWORLD:
            rv=PS_WORLD;
            break;
        case tPSOBJECT:
            rv=PS_OBJECT;
            break;
        case tPSSHADER:
            rv=PS_SHADER;
            break;
        case tPSCURRENT:
            rv=PS_CURRENT;
            break;
        case tPSNDC:
            rv=PS_NDC;
            break;
    }
    return rv;
}

int translate_spline(int stype)
{
    int rv=0;
    switch(stype){
        case tCATMULL_ROM:
            rv = SP_CATMULL_ROM;
            break;
        case tBEZIER:
            rv = SP_BEZIER;
            break;
        case tBSPLINE:
            rv = SP_BSPLINE;
            break;
        case tHERMITE:
            rv = SP_HERMITE;
            break;
        case tLINEAR:
            rv = SP_LINEAR;
            break;
    }
    return rv;
}
    
void emit(struct tree *t)
{
    switch (t->op) {
        case ',':
	    /* parameter list */
            emit(t->kids[1]);
            if (t->kids[0] != NULL)
                emit(t->kids[0]);
            break;
        case 'F':
	    /* Function parameter list */
            emit(t->kids[1]);
            break;
        case 'P':
	    /* function actual parameter expression */
            emit(t->kids[1]);
            if (t->ty == tSTRING){
                emit2(oASSIGNS, t->kids[0]->off);
            }    
            else if ( istriple(t->ty)){
                if(t->kids[0]->op == tINDEX3){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR3);
                }
                emit2(oASSIGN3, t->kids[0]->off);
            }
            else{
                if(t->kids[0]->op == tINDEX){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR);
                }
                emit2(oASSIGN, t->kids[0]->off);
            }
            break;
        case tFUNCTION:
            {
                struct func_tree *function = get_function_by_offset(t->off);
                struct tree *rv;
                check_params(function, t->kids[1]);
                rv = fix_ret_expr(function->func_code);
                insert_function(function->name);
                emit (rv);
            }
            break;
        case '=':
        case tRETURN:
            emit(t->kids[1]);
            /* check for chain assignment */
            if(t->kids[1]->op == '=')
                emit(t->kids[1]->kids[0]);
                
            if (t->ty == tSTRING){
                emit2(oASSIGNS, t->kids[0]->off);
            }    
            else if ( istriple(t->ty)){
                if(t->kids[0]->op == tINDEX3){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR3);
                }
                emit2(oASSIGN3, t->kids[0]->off);
            }
            else{
                if(t->kids[0]->op == tINDEX){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR);
                }
                emit2(oASSIGN, t->kids[0]->off);
            }
            break;
        case tPLUSEQ:
            emit(t->kids[1]);
            if ( istriple(t->ty)){
                if(t->kids[0]->op == tINDEX3){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR3);
                }            
                emit2(oADDEQ3, t->kids[0]->off);
            }
            else{
                if(t->kids[0]->op == tINDEX){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR);
                }
                emit2(oADDEQ, t->kids[0]->off);
            }
            break;
        case tMINUSEQ:
            emit(t->kids[1]);
            if ( istriple(t->ty) ){
                if(t->kids[0]->op == tINDEX3){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR3);
                }
                emit2(oSUBEQ3, t->kids[0]->off);
            }
            else{
                if(t->kids[0]->op == tINDEX){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR);
                }
                emit2(oSUBEQ, t->kids[0]->off);
            }
            break;
        case tTIMESEQ:
            emit(t->kids[1]);
            if ( istriple(t->ty)){
                if(t->kids[0]->op == tINDEX3){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR3);
                }
                emit2(oMULEQ3, t->kids[0]->off);
            }
            else{
                if(t->kids[0]->op == tINDEX){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR);
                }
                emit2(oMULEQ, t->kids[0]->off);
            }
            break;
        case tDIVEQ:
            emit(t->kids[1]);
            if ( istriple(t->ty)){
                if(t->kids[0]->op == tINDEX3){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR3);
                }
                emit2(oDIVEQ3, t->kids[0]->off);
            }
            else{
                if(t->kids[0]->op == tINDEX){
                    emit(t->kids[0]->kids[0]);
                    emit1(oARR);
                }
                emit2(oDIVEQ, t->kids[0]->off);
            }
            break;
        case tCVTF2TRIPLE:
	    /* convert float to triple */
            emit(t->kids[0]);
            emit1(oCF2T);
            break;
        case tPI:
            emit1(oPI);
            break;
        case '+':
            emit(t->kids[0]);
            emit(t->kids[1]);
            if ( istriple(t->ty))
                emit1(oADD3);
            else
                emit1(oADD);
            break;
        case '-':
            emit(t->kids[0]);
            emit(t->kids[1]);
            if ( istriple( t->ty))
                emit1(oSUB3);
            else
                emit1(oSUB);
            break;
        case '*':
            emit(t->kids[0]);
            emit(t->kids[1]);
            if ( istriple(t->ty))
                emit1(oMUL3);
            else
                emit1(oMUL);
            break;
        case '/':
            emit(t->kids[0]);
            emit(t->kids[1]);
            if ( istriple(t->ty) )
                emit1(oDIV3);
            else
                emit1(oDIV);
            break;
        case '.':
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oDOTP);
            break;
        case '^':
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oCROSSP);
            break;
        case tUMINUS:
            emit(t->kids[0]);
            emit1( isgeomtriple(t->ty)  ? oNEGATE3: oNEGATE);
            break;
        case tCOLOR:
        case tPOINT:
        case tVECTOR:
        case tNORMAL:
            emit2(oPUSH3, t->off);
            break;
        case tFLOAT:
            emit2(oPUSH, t->off);
            break;
        case tSTRING:
            emit2(oPUSHS, t->off);
            break;
        case tCSEXPR:
            emit(t->kids[0]);
            break;
        case tPSEXPR:
            emit(t->kids[0]);
            break;
        case tSPLINEEXPR:
            emit(t->kids[0]);
            break;
        case tINDEX:
            emit(t->kids[0]);
            emit1(oARR);
            emit2(oPUSH, t->off);
            break;
        case tINDEX3:
            emit(t->kids[0]);
            emit1(oARR3);
            emit2(oPUSH3, t->off);
            break;
        case tSIN:
            emit(t->kids[0]);
            emit1(oSIN);
            break;
        case tASIN:
            emit(t->kids[0]);
            emit1(oASIN);
            break;
        case tCOS:
            emit(t->kids[0]);
            emit1(oCOS);
            break;
        case tACOS:
            emit(t->kids[0]);
            emit1(oACOS);
            break;
        case tTAN:
            emit(t->kids[0]);
            emit1(oTAN);
            break;
        case tATAN:
            emit(t->kids[0]);
            emit1(oATAN);
            break;
        case tATAN2:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oATAN2);
            break;
        case tRADIANS:
            emit(t->kids[0]);
            emit1(oRADIANS);
            break;
        case tDEGREES:
            emit(t->kids[0]);
            emit1(oDEGREES);
            break;
        case tSQRT:
            emit(t->kids[0]);
            emit1(oSQRT);
            break;
        case tSQR:
            emit(t->kids[0]);
            emit1(oSQR);
            break;
        case tINVSQRT:
            emit(t->kids[0]);
            emit1(oINVSQRT);
            break;
        case tPOW:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oPOW);
            break;
        case tEXP:
            emit(t->kids[0]);
            emit1(oEXP);
            break;
        case tLOG:
            emit(t->kids[0]);
            if (t->kids[1] != NULL){
                emit(t->kids[1]);
                emit1(oLOG2);
            }
            else{
                emit1(oLOG);
            }
            break;
        case tMOD:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oMOD);
            break;
        case tABS:
            emit(t->kids[0]);
            emit1(oABS);
            break;
        case tSIGN:
            emit(t->kids[0]);
            emit1(oSIGN);
            break;
        case tMIN:
            emit(t->kids[0]);
            emit(t->kids[1]);
            if (t->kids[2] != NULL){
	    	/* if min has more than 2 args, then their list is in kids[2] */
                struct tree *tmp = t->kids[2];
                emit(t->kids[2]);
                while (tmp != NULL && tmp->op == ','){
                    emit1(oMIN);
                    tmp = tmp->kids[0];
                }
            }
            emit1(oMIN);
            break;
        case tMIN3:
            emit(t->kids[0]);
            emit(t->kids[1]);
            if (t->kids[2] != NULL){
                struct tree *tmp = t->kids[2];
                emit(t->kids[2]);
                while (tmp != NULL && tmp->op == ','){
                    emit1(oMIN3);
                    tmp = tmp->kids[0];
                }
            }
            emit1(oMIN3);
            break;
        case tMAX:
            emit(t->kids[0]);
            emit(t->kids[1]);
            if (t->kids[2] != NULL){
                struct tree *tmp = t->kids[2];
                emit(t->kids[2]);
                while (tmp != NULL && tmp->op == ','){
                    emit1(oMAX);
                    tmp = tmp->kids[0];
                }
            }
            emit1(oMAX);
            break;
        case tMAX3:
            emit(t->kids[0]);
            emit(t->kids[1]);
            if (t->kids[2] != NULL){
                struct tree *tmp = t->kids[2];
                emit(t->kids[2]);
                while (tmp != NULL && tmp->op == ','){
                    emit1(oMAX3);
                    tmp = tmp->kids[0];
                }
            }
            emit1(oMAX3);
            break;
        case tCLAMP:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oCLAMP);
            break;
        case tCLAMP3:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oCLAMP3);
            break;
        case tCEIL:
            emit(t->kids[0]);
            emit1(oCEIL);
            break;
        case tFLOOR:
            emit(t->kids[0]);
            emit1(oFLOOR);
            break;
        case tROUND:
            emit(t->kids[0]);
            emit1(oROUND);
            break;
        case tSTEP:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oSTEP);
            break;
        case tSMOOTHSTEP:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oSMOOTHSTEP);
            break;
        case tCOMP:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oCOMP);
            break;
        case tXCOMP:
            emit(t->kids[0]);
            emit1(oXCOMP);
            break;
        case tYCOMP:
            emit(t->kids[0]);
            emit1(oYCOMP);
            break;
        case tZCOMP:
            emit(t->kids[0]);
            emit1(oZCOMP);
            break;
        case tLENGTH:
            emit(t->kids[0]);
            emit1(oLENGTH);
            break;
        case tDISTANCE:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oDISTANCE);
            break;
        case tAREA:
            emit(t->kids[0]);
            emit1(oAREA);
            break;
        case tNORMALIZE:
            emit(t->kids[0]);
            emit1(oNORMALIZE);
            break;
        case tFACEFORWARD:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oFACEFORWARD);
            break;
        case tREFLECT:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oREFLECT);
            break;
        case tREFRACT:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oREFRACT);
            break;
        case tCALCULATENORMAL:
            emit(t->kids[0]);
            emit1(oCALCULATENORMAL);
            break;
        case tMIX:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oMIX);
            break;
        case tMIX3:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oMIX3);
            break;
        case tNOISE:
            {
                int dim;
                if (t->kids[0]->ty == tFLOAT)
                    dim = 1;
                else
                    dim = 3;
                emit(t->kids[0]);
                if (t->kids[1] != NULL){
                    emit(t->kids[1]);
                    ++dim;
                }
                emit2(oNOISE, dim);
            }
            break;
        case tNOISE3:
            {
                int dim;
                if (t->kids[0]->ty == tFLOAT)
                    dim = 1;
                else
                    dim = 3;
                emit(t->kids[0]);
                if (t->kids[1] != NULL){
                    emit(t->kids[1]);
                    ++dim;
                }
                emit2(oNOISE3, dim);
            }
            break;
        case tCELLNOISE:
            {
                int dim;
                if (t->kids[0]->ty == tFLOAT)
                    dim = 1;
                else
                    dim = 3;
                emit(t->kids[0]);
                if (t->kids[1] != NULL){
                    emit(t->kids[1]);
                    ++dim;
                }
                emit2(oCELLNOISE, dim);
            }
            break;
        case tCELLNOISE3:
            {
                int dim;
                if (t->kids[0]->ty == tFLOAT)
                    dim = 1;
                else
                    dim = 3;
                emit(t->kids[0]);
                if (t->kids[1] != NULL){
                    emit(t->kids[1]);
                    ++dim;
                }
                emit2(oCELLNOISE3, dim);
            }
            break;
        case tPNOISE:
            {
                int dim;
                if (t->kids[0]->ty == tFLOAT)
                    dim = 1;
                else
                    dim = 3;
                emit(t->kids[0]);
                emit(t->kids[1]);
                if (t->kids[2] != NULL){
                    ++dim;
                    emit(t->kids[2]);
                    emit(t->kids[3]);
                }
                emit2(oPNOISE, dim);
            }
            break;
        case tPNOISE3:
            {
                int dim;
                if (t->kids[0]->ty == tFLOAT)
                    dim = 1;
                else
                    dim = 3;
                emit(t->kids[0]);
                emit(t->kids[1]);
                if (t->kids[2] != NULL){
                    ++dim;
                    emit(t->kids[2]);
                    emit(t->kids[3]);
                }
                emit2(oPNOISE3, dim);
            }
            break;
        case tTRANSFORM:
            emit(t->kids[0]);
            if (t->kids[1]->op == tPSEXPR)
                emit(t->kids[1]);
            if (t->kids[2]->op == tPSEXPR)
                emit(t->kids[2]);
            emit3(oTRANSFORM, translate_pspace(t->kids[1]->op), 
                    translate_pspace(t->kids[2]->op));
            break;            
        case tNTRANSFORM:
            emit(t->kids[0]);
            if (t->kids[1]->op == tPSEXPR)
                emit(t->kids[1]);
            if (t->kids[2]->op == tPSEXPR)
                emit(t->kids[2]);
            emit3(oNTRANSFORM, translate_pspace(t->kids[1]->op), 
                    translate_pspace(t->kids[2]->op));
            break;            
        case tVTRANSFORM:
            emit(t->kids[0]);
            if (t->kids[1]->op == tPSEXPR)
                emit(t->kids[1]);
            if (t->kids[2]->op == tPSEXPR)
                emit(t->kids[2]);
            emit3(oVTRANSFORM, translate_pspace(t->kids[1]->op), 
                    translate_pspace(t->kids[2]->op));
            break;            
        case tAMBIENT:
            emit1(oAMBIENT);
            break;
        case tDIFFUSE:
            emit(t->kids[0]);
            emit1(oDIFFUSE);
            break;
        case tPHONG:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oPHONG);
            break;
        case tSPECULAR:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oSPECULAR);
            break;
        case tSPECULARBRDF:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit(t->kids[3]);
            emit1(oSPECULARBRDF);
            break;
        case tTRACE:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oTRACE);
            break;
        case tSPLINE:
            emit(t->kids[1]);   /* the data points */
            emit2(oPUSHC, llen(t->kids[1])); /* data vec. len */
            emit(t->kids[0]);   /* the index expression */
            if (t->kids[2]->op == tSPLINEEXPR)
                emit(t->kids[2]);
            emit2(oSPLINE, translate_spline(t->kids[2]->op) );
            break;
        case tSPLINE3:
            emit(t->kids[1]);   /* the data expression */
            emit2(oPUSHC, llen(t->kids[1])); /* data vec. len */
            emit(t->kids[0]);   /* the index expression */
            if (t->kids[2]->op == tSPLINEEXPR)
                emit(t->kids[2]);
            emit2(oSPLINE3, translate_spline(t->kids[2]->op));
            break;            
        case tSPLINEARR:
            {
                int offset =  t->kids[1]->kids[1]->off;
                emit2(oPUSHARR, offset);
                emit2(oPUSHALEN, offset);
                emit(t->kids[0]);   /* the index expression */
                if (t->kids[2]->op == tSPLINEEXPR)
                    emit(t->kids[2]);
                emit2(oSPLINE, translate_spline(t->kids[2]->op));
            }
            break;
        case tSPLINEARR3:
            {
                int offset = t->kids[1]->kids[1]->off;
                struct _sym * arr = getsym(offset);
                emit2(oPUSHARR3, offset);
                emit2(oPUSHALEN, offset);
                emit(t->kids[0]);   /* the index expression */
                if (t->kids[2]->op == tSPLINEEXPR)
                    emit(t->kids[2]);
                emit2(oSPLINE3, translate_spline(t->kids[2]->op));
            }
            break;            
        case tSETCOMP:
            emit(t->kids[1]);
            emit(t->kids[2]);
            if(t->kids[0]->op == tINDEX3){
                emit(t->kids[0]->kids[0]);
                emit1(oARR);
            }
            emit2(oSETCOMP, t->kids[0]->off);        
            break;
        case tSETXCOMP:
            emit(t->kids[1]);
            if(t->kids[0]->op == tINDEX3){
                emit(t->kids[0]->kids[0]);
                emit1(oARR);
            }
            emit2(oSETXCOMP, t->kids[0]->off);        
            break;
        case tSETYCOMP:
            emit(t->kids[1]);
            if(t->kids[0]->op == tINDEX3){
                emit(t->kids[0]->kids[0]);
                emit1(oARR);
            }
            emit2(oSETYCOMP, t->kids[0]->off);        
            break;
        case tSETZCOMP:
            emit(t->kids[1]);
            if(t->kids[0]->op == tINDEX3){
                emit(t->kids[0]->kids[0]);
                emit1(oARR);
            }
            emit2(oSETZCOMP, t->kids[0]->off);        
            break;
        case tTRIPLEEXPR:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            break;
        case tCTRANSFORM:
            emit(t->kids[0]);
            if (t->kids[1]->op == tCSEXPR)
                emit(t->kids[1]);
            if (t->kids[2]->op == tCSEXPR)
                emit(t->kids[2]);
            emit3(oCTRANSFORM, translate_cspace(t->kids[1]->op), 
                        translate_cspace(t->kids[2]->op));
            break;
        case tRANDOM:
            emit1(oRANDOM);
            break;
        case tRANDOM3:
            emit1(oRANDOM3);
            break;
        case tDU:
            emit(t->kids[0]);
            emit1(oDU);
            break;
        case tDU3:
            emit(t->kids[0]);
            emit1(oDU3);
            break;
        case tDV:
            emit(t->kids[0]);
            emit1(oDV);
            break;
        case tDV3:
            emit(t->kids[0]);
            emit1(oDV3);
            break;
        case tDERIV:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oDERIV);
            break;
        case tDERIV3:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit1(oDERIV3);
            break;
        case tFRESNEL:
            if (t->kids[2] != NULL && t->kids[3]!=NULL)
                emit1(oFRESNEL2);
            else
                emit1(oFRESNEL);
            if(t->kids[0]->op == tINDEX){
                emit(t->kids[0]->kids[0]);
                emit1(oARR);
            }
            emit2(oASSIGN, t->kids[0]->off);
            if(t->kids[1]->op == tINDEX){
                emit(t->kids[1]->kids[0]);
                emit1(oARR);
            }
            emit2(oASSIGN, t->kids[1]->off);
            if (t->kids[2] != NULL){
                if(t->kids[2]->op == tINDEX3){
                    emit(t->kids[2]->kids[0]);
                    emit1(oARR3);
                }
                emit2(oASSIGN3, t->kids[2]->off);
            }
            if (t->kids[3] != NULL){
                if(t->kids[3]->op == tINDEX3){
                    emit(t->kids[3]->kids[0]);
                    emit1(oARR3);
                }
                emit2(oASSIGN3, t->kids[3]->off);
            }
            break;
        case tDEPTH:
            emit(t->kids[0]);
            emit1(oDEPTH);
            break;
        case tPTLINED:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit1(oPTLINED);
            break;
        case tROTATE:
            emit(t->kids[0]);
            emit(t->kids[1]);
            emit(t->kids[2]);
            emit(t->kids[3]);
            emit1(oROTATE);
            break;
        case tQU:
            {
                int val1, val2, val3, val4;
                struct ilist * pilist;
                emit(t->kids[0]);
                val1 = get_dot();
                emit(t->kids[1]);
                val2 = get_dot();
                pilist = mkilist(val2+1);
                emit2(oJMP, 0);
                val3 = get_dot();
                emit(t->kids[2]);
                val4 = get_dot();
                backpatch(t->kids[0]->tree_patch.false, val3);
                backpatch(pilist, val4);
            }
            break;
        case tEQ:
        case tEQ3:
            emit(t->kids[0]);
            emit(t->kids[1]);
            t->tree_patch.false = mkilist(get_dot()+1);
            if (t->kids[0]->ty == tSTRING)
                emit2(oNES, 0);
            else if (t->op == tEQ)
                emit2(oNE, 0);
            else
                emit2(oNE3, 0);
            break;
        case tNE:
        case tNE3:
            emit(t->kids[0]);
            emit(t->kids[1]);            
            t->tree_patch.false = mkilist(get_dot()+1);
            if (t->kids[0]->ty == tSTRING)
                emit2(oEQS, 0);
            else if (t->op == tNE)
                emit2(oEQ, 0);
            else
                emit2(oEQ3,0);
            break;
        case tGT:
            emit(t->kids[0]);
            emit(t->kids[1]);
            t->tree_patch.false = mkilist(get_dot()+1);
            emit2(oLE, 0);
            break;
        case tLT:
            emit(t->kids[0]);
            emit(t->kids[1]);
            t->tree_patch.false = mkilist(get_dot()+1);
            emit2(oGE, 0);
            break;
        case tGE:
            emit(t->kids[0]);
            emit(t->kids[1]);
            t->tree_patch.false = mkilist(get_dot()+1);
            emit2(oLT, 0);
            break;
        case tLE:
            emit(t->kids[0]);
            emit(t->kids[1]);
            t->tree_patch.false = mkilist(get_dot()+1);
            emit2(oGT, 0);
            break;
        case tOR:
            {
                struct ilist * pilist;
                int val1, val2, val3;
                emit(t->kids[0]);
                val1 = get_dot();
                pilist = mkilist(val1+1);
                emit2(oJMP, 0);
                val2 = get_dot();
                emit(t->kids[1]);
                val3 = get_dot();
                backpatch(t->kids[0]->tree_patch.false, val2);
                backpatch(pilist, val3);
                t->tree_patch.false = t->kids[1]->tree_patch.false;
            }        
            break;
        case tAND:
            {
                int val1;
                emit(t->kids[0]);
                val1 = get_dot();
                emit(t->kids[1]);
                t->tree_patch.false = merge(t->kids[0]->tree_patch.false,
                        t->kids[1]->tree_patch.false);
            }        
            break;
        case tNULLOP:
            /* do nothing */
            break;
        default:
            fprintf(stderr, "ERROR: Unknown op: %d\n", t->op);
            exit(1);
    }
}

