%{
/****************************************************************************

FILE      tokens.l

PURPOSE
        This file contains shading language tokens parsing file for lex.

****************************************************************************/
/****************************************************************************
 Copyright (c) 1995.
      Robert J. Mercier
  Copyright 2000
      Vahur Krouverk

 THIS CODE IS SUPPLIED ``AS IS'' WITH NO WARRANTY EXPRESSED
 OR IMPLIED.  NO CLAIMS IS MADE TO IT'S SUITABILITY FOR
 ANY PURPOSE AND NO RESPONSIBILITY IS ACCEPTED FOR ANY DAMAGES
 OF ANY KIND RESULTING FROM IT'S USE.

 When (if) this code is included into POV the usual POV legal stuff will apply.

*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "shade.h"
#include "y.tab.h"
#include "shmem.h"
#include "slgram.h"
%}

identifier [A-Za-z][A-Za-z0-9_]*
number [0-9]+
exponent [eE][-+]?{number}
fraction ({number}?"."{number})|({number}".")
real ({fraction}{exponent}?)|({number}{exponent})|({number})

simple_escape [abfnrtv'"?\\%]
octal_escape  [0-7]{1,3}
hex_escape "x"[0-9a-fA-F]+

escape_sequence [\\]({simple_escape}|{octal_escape}|{hex_escape})
s_char [^"\\\n]|{escape_sequence}

%state GLOBAL
%state COMMENT

%%
                                {BEGIN GLOBAL;}            

<GLOBAL>"void"              return tVOID;
<GLOBAL>"varying"           return tVARYING;
<GLOBAL>"uniform"           return tUNIFORM;
<GLOBAL>"output"            return tOUTPUT;
<GLOBAL>"extern"            return tEXTERN;
<GLOBAL>"displacement"      return tDISPLACEMENT;
<GLOBAL>"surface"           return tSURFACE;
<GLOBAL>"iso_function"      return tISO_FUNCTION;
<GLOBAL>"color"             return tCOLOR;
<GLOBAL>"point"             return tPOINT;
<GLOBAL>"normal"            return tNORMAL;
<GLOBAL>"vector"            return tVECTOR;
<GLOBAL>"float"             return tFLOAT;
<GLOBAL>"string"            return tSTRING;
<GLOBAL>"if"                return tIF;
<GLOBAL>"else"              return tELSE;
<GLOBAL>"while"             return tWHILE;
<GLOBAL>"do"                return tDO;
<GLOBAL>"for"               return tFOR;
<GLOBAL>"break"             return tBREAK;
<GLOBAL>"continue"          return tCONTINUE;
<GLOBAL>"return"            return tRETURN;


<GLOBAL>"noise"             return tNOISE;
<GLOBAL>"pnoise"            return tPNOISE;
<GLOBAL>"sin"               return tSIN;
<GLOBAL>"asin"              return tASIN;
<GLOBAL>"cos"               return tCOS;
<GLOBAL>"acos"              return tACOS;
<GLOBAL>"tan"               return tTAN;
<GLOBAL>"atan"              return tATAN;
<GLOBAL>"radians"           return tRADIANS;
<GLOBAL>"degrees"           return tDEGREES;
<GLOBAL>"sqrt"              return tSQRT;
<GLOBAL>"sqr"              return tSQR;
<GLOBAL>"inversesqrt"       return tINVSQRT;
<GLOBAL>"pow"               return tPOW;
<GLOBAL>"exp"               return tEXP;
<GLOBAL>"log"               return tLOG;
<GLOBAL>"mod"               return tMOD;
<GLOBAL>"abs"               return tABS;
<GLOBAL>"sign"              return tSIGN;
<GLOBAL>"min"               return tMIN;
<GLOBAL>"max"               return tMAX;
<GLOBAL>"clamp"             return tCLAMP;
<GLOBAL>"ceil"              return tCEIL;
<GLOBAL>"floor"             return tFLOOR;
<GLOBAL>"round"             return tROUND;
<GLOBAL>"step"              return tSTEP;
<GLOBAL>"smoothstep"        return tSMOOTHSTEP;
<GLOBAL>"spline"            return tSPLINE;

<GLOBAL>"xcomp"             return tXCOMP;
<GLOBAL>"ycomp"             return tYCOMP;
<GLOBAL>"zcomp"             return tZCOMP;
<GLOBAL>"setxcomp"          return tSETXCOMP;
<GLOBAL>"setycomp"          return tSETYCOMP;
<GLOBAL>"setzcomp"          return tSETZCOMP;
<GLOBAL>"length"            return tLENGTH;
<GLOBAL>"distance"          return tDISTANCE;
<GLOBAL>"area"              return tAREA;
<GLOBAL>"normalize"         return tNORMALIZE;
<GLOBAL>"faceforward"       return tFACEFORWARD;
<GLOBAL>"reflect"           return tREFLECT;
<GLOBAL>"refract"           return tREFRACT;
<GLOBAL>"fresnel"           return tFRESNEL;
<GLOBAL>"transform"         return tTRANSFORM;
<GLOBAL>"vtransform"        return tVTRANSFORM;
<GLOBAL>"ntransform"        return tNTRANSFORM;
<GLOBAL>"depth"             return tDEPTH;
<GLOBAL>"calculatenormal"   return tCALCULATENORMAL;
<GLOBAL>"mix"               return tMIX;
<GLOBAL>"comp"              return tCOMP;
<GLOBAL>"setcomp"           return tSETCOMP;
<GLOBAL>"ctransform"        return tCTRANSFORM;
<GLOBAL>"cellnoise"         return tCELLNOISE;
<GLOBAL>"random"            return tRANDOM;
<GLOBAL>"ambient"           return tAMBIENT;
<GLOBAL>"diffuse"           return tDIFFUSE;
<GLOBAL>"phong"             return tPHONG;
<GLOBAL>"specular"          return tSPECULAR;
<GLOBAL>"specularbrdf"      return tSPECULARBRDF;
<GLOBAL>"illuminance"       return tILLUMINANCE;
<GLOBAL>"trace"             return tTRACE;
<GLOBAL>"ptlined"           return tPTLINED;
<GLOBAL>"rotate"            return tROTATE;

<GLOBAL>"atmosphere"        return tATMOSPHERE;
<GLOBAL>"lightsource"       return tLIGHTSOURCE;


<GLOBAL>"Du"                return tDU;
<GLOBAL>"Dv"                return tDV;
<GLOBAL>"Deriv"             return tDERIV;

<GLOBAL>"printf"            return tPRINTF;

<GLOBAL>"=="                return tEQ;
<GLOBAL>"!="                return tNE;
<GLOBAL>">="                return tGE;
<GLOBAL>"<="                return tLE;
<GLOBAL>">"                 return tGT;
<GLOBAL>"<"                 return tLT;
<GLOBAL>"||"                return tOR;
<GLOBAL>"&&"                return tAND;
<GLOBAL>"+="                return tPLUSEQ;
<GLOBAL>"-="                return tMINUSEQ;
<GLOBAL>"*="                return tTIMESEQ;
<GLOBAL>"/="                return tDIVEQ;

<GLOBAL>"PI"                return tPI;

<GLOBAL>["]{s_char}*["]  { 
        yylval.s = strsave(yytext);
        return tSCONST; 
    }

<GLOBAL>{identifier} {
        yylval.s = strsave(yytext);
        return tID; 
    }


<GLOBAL>{real} { 
        yylval.f = strtod(yytext, NULL);
        return tFCONST; 
    }

<GLOBAL>[ \t\r\b]           /* do nothing */;

"\n"                lineno++;

^"#".*"\n"  {
                    /* handle #line directives in preprocessed files */
                    int new_line_no=0;
                    char fname[FILENAME_MAX];
                    if (sscanf(yytext,"# %d %s", &new_line_no, fname)==2){
                        lineno = new_line_no;
                        cur_input_file = strsave(fname);
                    }
                    else if (sscanf(yytext,"#line %d %s", &new_line_no, fname)==2){
                        lineno = new_line_no;
                        cur_input_file = strsave(fname);
                    }
                    else{
                        lineno++;
                    }
                }


<GLOBAL>.               return yytext[0];


<GLOBAL>"/*"                            {BEGIN COMMENT;}
<COMMENT>.                              ;
<COMMENT>"*/"                           {BEGIN GLOBAL;}

<GLOBAL>"//".*"\n"                      lineno++;


%%

int yywrap()
{
    return 1;       /* EOF means quit */
}
