#ifndef SHDRVARS_H
#define SHDRVARS_H
/****************************************************************************

FILE	shdrvars.h

PURPOSE 
    	This file contains declarations for shader structures and functions.
	
*****************************************************************************/
/*****************************************************************************                                                                              
 Copyright (c) 1995
      Robert J. Mercier
 Copyright 2000
      Vahur Krouverk

THIS CODE IS SUPPLIED ``AS IS'' WITH NO WARRANTY EXPRESSED
OR IMPLIED.  NO CLAIMS IS MADE TO IT'S SUITABILITY FOR
ANY PURPOSE AND NO RESPONSIBILITY IS ACCEPTED FOR ANY DAMAGES
OF ANY KIND RESULTING FROM IT'S USE.

When (if) this code is included into POV the usual POV legal stuff will apply.

*****************************************************************************/


#include "shdrglue.h"
#include "texture.h"
#include "shdrglob.h"


typedef struct _sym {
    char *name;
    short type;
    short slot;
    short dim;
    short block;
    short initializer;
    struct _sym *next;
} sym_t;


#define HSIZE       11
typedef struct _shader {
    char            *filename;          /* object file shader is from */
    char            *name;              /* shader name (not used) */
    int             shadertype;         /* type of shader */
    unsigned char   *code;              /* bytecode */
    DBL             *data_templ;        /* data vector */
    int             *dimarr;            /* for array dimension RT checking */
    char            **strings;          /* string table */
    short           dsize;
    short           csize;
    short           nstring;
    sym_t           *htab[HSIZE];
    int             uvused;
    struct _shader  *next;              /* for global shader hash table */
    int             dynastring;
    int             refcount;
    int             startaddr;
    int             initialized;
} shader_t;

typedef struct _stringtab{
    int allocated;        /* if 0, then string points to shader_t string table entry,
                             if 1, then string is allocated separately and
                             should be freed by owner of this str
                          */
    char *string;
}stringtab;

typedef struct {
    pov_arg_t    *args;
    pov_arg_t    *Os_arg;              /* pointer to opacity in args list */
    shader_t     *shader;
    DBL          *data;                /* data vector */
    RAY          *Eye_Ray;
    LIGHT_SOURCE *Light;
    PIGMENT      *Current_Pigment;
    short        ambient_init;
    enum SHADOW_TYPE shadow;
    stringtab    *inst_strings;
    int          refcount;
    int          warning_flag;  /* indicates, whether warning is issued, 
                                    if shader data is incomplete: only 
                                    information about intersection point is 
                                    provided in this case */
    int         inst_startaddr;
} shader_inst_t;


extern shader_t * shaders[HSIZE];

void reset_shader_count();
int s_hash(char *s);
void shader_transform(shader_inst_t* Shader, VECTOR Result, 
        VECTOR Initial, int To_Space, int From_Space, int Transform_Type);
int s_getdim(shader_t *p, int offset);
void s_execute(shader_inst_t *pi);
#endif

